==> parted-1.2.3.tar.gz: parted-1.2.3/parted/ui.h <==
/*
    parted - a frontend to libparted
    Copyright (C) 1999  Andrew Clausen, Lennert Buytenhek and Red Hat, Inc.

    Andrew Clausen		<clausen@gnu.org>
    Lennert Buytenhek		<buytenh@gnu.org>
    Matt Wilson, Red Hat Inc.	<msw@redhat.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef UI_H_INCLUDED
#define UI_H_INCLUDED

#define MEGABYTE (1024 * 1024)
#define MEGABYTE_SECTORS (MEGABYTE / 512)

extern char*	prog_name;

extern int init_ui ();
extern int non_interactive_mode (PedDevice* dev, Command* cmd_list[],
				 int argc, char* argv[]);
extern int interactive_mode (PedDevice* dev, Command* cmd_list[]);
extern void done_ui ();

extern int screen_width ();

extern char* get_word ();
extern int get_integer ();
extern PedSector get_sector ();
extern char* peek_word ();
extern int is_integer ();
extern int is_sector ();
extern int count_words ();

extern void help_msg ();

/* in parted.c */
extern int	opt_script_mode;

extern int do_help (PedDevice* dev);
extern void print_options_help ();
extern void print_commands_help ();

#endif /* UI_H_INCLUDED */

==> parted-1.4.14.tar.gz: parted-1.4.14/parted/ui.h <==
/*
    parted - a frontend to libparted
    Copyright (C) 1999, 2000 Free Software Foundation, Inc.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef UI_H_INCLUDED
#define UI_H_INCLUDED

#define MEGABYTE (1024 * 1024)
#define MEGABYTE_SECTORS (MEGABYTE / 512)

extern char*	prog_name;

extern int init_ui ();
extern int non_interactive_mode (PedDevice* dev, Command* cmd_list[],
				 int argc, char* argv[]);
extern int interactive_mode (PedDevice* dev, Command* cmd_list[]);
extern void done_ui ();

extern int screen_width ();

extern char* get_word ();
extern int get_integer ();
extern PedSector get_sector ();
extern int get_state ();
extern char* peek_word ();
extern int is_integer ();
extern int is_sector ();
extern int count_words ();

extern void help_msg ();

extern void print_using_dev (PedDevice* dev);

/* in parted.c */
extern int	opt_script_mode;

extern int do_help (PedDevice** dev);
extern void print_options_help ();
extern void print_commands_help ();


#endif /* UI_H_INCLUDED */
